<?php
/**
 * Metag Text
 * @package     Metag
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Metag_Text extends Metag
{
    /**
     * タグタイプ
     * @var string
     */
    public $node_type = 'text';
    /**
     * 表示名
     * @var string
     */
    public $display_name = 'テキスト (text)';
    /**
     * ブロック要素かどうか
     * @var boolean
     */
    public $is_block = false;
    /**
     * maxlength
     * @var string
     */
    public $maxlength;
    /**
     * style attribute
     * @var string
     */
    public $style;
    /**
     * 属性リスト
     * @var array
     */
    public $attr_list = array(
        'id' => 'id',
        'initial_value' => 'initial_value',
        'style' => 'style',
        'maxlength' => 'maxlength',
        'anchor' => 'anchor',
        'ref_id' => 'ref_id',
        'ref_page_id' => 'ref_page_id',
        'ref_link' => 'ref_link',
    );

    /**
     * 編集viewの開始タグ出力
     * @param array $row
     */
    public function edit_view($row)
    {
        // 参照指定がある場合は子HTMLを出力
        if (strlen($this->ref_id) > 0) {
            $child = $this->get_child_node();
            echo $child->node_value;
            return;
        }
        h::no_escape('<span class="metag" onclick="' . $this->get_open_method($row) . '"'
                . $this->get_style($row['repeat_no']) . '>'
                . $this->output($row, true)
                . '</span>');
    }

    /**
     * 出力
     * @param array $row
     * @param boolean $edit_mode
     * @return string $ret
     */
    public function output($row, $edit_mode = false)
    {
        $ret = '';
        if ($edit_mode && (strlen($row['node_value']) < 1 || preg_match('/^[[:cntrl:]]+$/', $row['node_value']))) {
            $ret = Metag_Logic::BLANK;
        } else {
            $ret = Me_Util::html_escape($row['node_value']);
        }
        $this->set_url($row);
        list($a_open, $a_close) = $this->get_a($row);
        $anchor = $this->get_anchor($row);
        $ret = $anchor . $a_open . $ret . $a_close;
        return $ret;
    }

    /**
     * editor
     */
    public function print_editor_attr()
    {
        $str = '';
        if (!empty($this->style)) {
            $str .= ' style="' . Me_Util::html_escape($this->style) . '"';
        }
        if (!empty($this->maxlength)) {
            $str .= ' maxlength="' . Me_Util::html_escape($this->maxlength) . '"';
        }
        h::no_escape($str);
    }

    /**
     * タグ編集
     */
    public function set_post_data()
    {
        $mapping = $this->attr_list;
        $mapping['selected_text'] = 'selected_text';
        Me_Util::post_data_to_object($this, $mapping);
    }
}