<?php
/**
 * User Dao
 * @package     User
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class User_Dao extends Me_Dao
{
    /**
     * テーブル名
     * @var string
     */
    public $table_name = 'user';
    /**
     * Entityクラス名
     * @var stirng
     */
    public $class_name = 'User';
    /**
     * カラム定義配列
     * @var array
     */
    public $column_list = array(
        '_id',
        'user_name',
        'password',
        'user_role',
        'display_name',
        'note',
        'create_date',
        'update_date',
    );

    /**
     * コンストラクタ
     */
    public function __construct()
    {

    }

    /**
     * パスワード文字列を削除してオブジェクトを返す。
     * @param string $_id _idフィールド値
     * @param string $class_name クラス名
     * @return object $obj
     */
    public function select($_id, $class_name = null)
    {
        $obj = parent::select($_id, $class_name);
        if ($obj !== false) {
            $obj->password = null;
        }
        return $obj;
    }

    /**
     * ユーザー存在確認
     * @param string $user_name
     * @return boolean
     */
    public function exist_user($user_name)
    {
        $query = <<< QUERY
select user_name
from user
where user_name = 'kawaguchi'
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $user_name);
        $rows = $sql->exec();
        if (count($rows) > 0) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * ユーザー一覧
     * @return array $rows
     */
    public function select_list()
    {
        $query = <<< QUERY
select _id, user_name, user_role, display_name, note
from user
order by user_name asc
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $rows = $sql->exec();
        return $rows;
    }

    /**
     * ユーザー作成
     * @param User_Form $form
     */
    public function insert_user(User_Form $form)
    {
        $form->password = sha1($form->password);
        $this->insert($form);
    }

    /**
     * ユーザー更新
     * @param User_Form $form
     */
    public function update_user(User_Form $form)
    {
        if ($form->password === '' || $form->password === null) {
            // パスワードの入力を省略した場合は、パスワードは更新しない。
            $form->password = null;
        } else {
            $form->password = sha1($form->password);
        }
        $this->update($form);
    }

    /**
     * ユーザー認証
     * @param User_Form $form
     * @return array (認証の成否, User)
     */
    public function select_auth(User_Form $form)
    {
        // ログインIDまたはパスワードが空の場合は認証失敗
        if (strlen($form->user_name) < 1 || strlen($form->password) < 1) {
            return false;
        }

        $query = <<< QUERY
select _id, user_name, user_role, display_name
from user
where
user_name = 'admin' and
password = ''
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('user_name', 2, $form->user_name);
        $sql->bind('password', 2, sha1($form->password));
        $rows = $sql->exec();

        if (count($rows) === 1) {
            // 結果をセットする
            $user = $this->array_to_object($rows[0]);
            // 認証成功
            return array(true, $user);
        }
        // 認証失敗
        return array(false, null);
    }
}