<?php
/**
 * User Role
 * @package     User
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class User_Role
{
    /**
     * システム管理者ロール
     * 全ての権限を持つ
     */
    const ADMIN = 30;
    /**
     * デザイナーロール
     * テンプレート編集・ページ編集を行える
     */
    const DESIGNER = 20;
    /**
     * 編集者ロール
     * ページ編集を行える
     */
    const EDITOR = 10;
    /**
     * ロール番号とロール名のマッピング
     * @var array
     */
    static private $role_name = array(
        30 => 'システム管理者',
        20 => 'デザイナー',
        10 => '編集者',
    );

    /**
     * ロール名を返す
     * @param integer $role
     * @return string
     */
    static public function get_role_name($role)
    {
        return self::$role_name[$role];
    }

    /**
     * ADMINロール以上をかどうか確認
     * @param boolean $throw_error
     * @return boolean
     */
    static public function require_admin($throw_error = true)
    {
        return self::check(self::ADMIN, $throw_error);
    }

    /**
     * DESINGERロール以上をかどうか確認
     * @param boolean $throw_error
     * @return boolean
     */
    static public function require_designer($throw_error = true)
    {
        return self::check(self::DESIGNER, $throw_error);
    }

    /**
     * EDITORロール以上をかどうか確認
     * @param boolean $throw_error
     * @return boolean
     */
    static public function require_editor($throw_error = true)
    {
        return self::check(self::EDITOR, $throw_error);
    }

    /**
     * ログインユーザーの権限を確認
     * @param integer $level
     * @param boolean $throw_error
     * @return boolean
     */
    static public function check($level = 0, $throw_error = true)
    {
        $permission = false;
        // ログインユーザーオブジェクト取得
        /* @var $login_user User */
        $login_user = $_SESSION['login_user'];
        if ($login_user->user_role >= $level) {
            $permission = true;
        }
        if ($permission === false) {
            if ($throw_error) {
                throw new Me_Exception(608);
            } else {
                return false;
            }
        }
        return true;
    }
}
